==> black_hole-8.x-1.10.tar.gz: black_hole/Readme.md <==
*README // BLACK HOLE theme for Drupal 8, 9 and 10.*

Thank you for downloading this theme!


ABOUT THE BLACK HOLE THEME:
===========================

**Black Hole** is an advanced responsive, mobile first, HTML5 theme with layout and style configuration options built in that you can control through Drupal's UI. The theme is a highly customized and feature-rich design that goes beyond the basic look and feel of a typical Drupal website. It uses [Yahoo Pure.css](https://purecss.io), a powerful responsive CSS framework and also fully supports right to left languages. Pure is ridiculously tiny. The entire set of modules clocks in at 3.5KB minified and gzipped.

The theme **validates HTML5 and CSS3**, it is cross-browser compatible, and it complies with [WAVE](https://wave.webaim.org/) and [FAE](https://fae.cita.uiuc.edu/).

**8.x-1.x** is a complete redesign made with mobile and SEO in mind: compatible, light and fast.


Theme's features
----------------------------------------

- 1, 2, or 3 column layout with customizable widths using [Yahoo Pure.css Framework](https://purecss.io);
- 15 block regions;
- 12 colour styles + themer setting. Choose themer style from theme's settings and then make appropriate modifications of /_custom/custom-style.css;
- **Helpful body classes** (unique classes for each page, term, website section, etc.);
- Themed blocks, block icons, page icons;
- Drop-down Main menu;
- Primary/secondary links menu position (center, left, right);
- Two font families;
- Different font sizes;
- Round corners for page elements and menus;
- Header image rotator;
- Full breadcrumb;
- Possibility to **change "Submitted by" display** on all nodes;
- **Advanced SEO optimization**;
- Theme's own slideshow with Multilingual support;
- Social links integration;
- **Bi-directional right to left (RTL) theming**;
- The possibility of having different logos depending on the language;
- Works perfect in Multilingual installations.


Advanced theme settings features
----------------------------------------

### Pure.CSS settings

- Responsive CSS files served from Yahoo CDN or locally;
- Layout with fixed or fluid width;
- Customizable width for First and Second sidebars;
- Feature to choose the blocks visible on mobile devices.


### Layout settings

- 12 color style options: Star Nebula, Protostar, Star, Red Giant, Planetary Nebula, Planet, White Dwarf, Massive Star, Red Supergiant, Supernova, Neutron Star, Black Hole and Themer;
- Two font families (Sans-Serif and Montserrat);
- 3 font size settings;
- Themed blocks;
- 32x32 pixel or 48x48 pixels Block icons for the themed blocks;
- Main Drop-down menu and secondary menu can be positioned (center, left, right);
- Three options for Search submit: button, icon or none;
- Page icons - choose a layout with or without page icons;
- Rounded corners for page elements and menus;
- Header image rotator;
- Duplicate the Main Menu at the bottom of the page.


### Other settings

- Breadcrumbs - display or not;
- Ability to change author and date information on all node types or differently for blog posts and forum topics;
- Replace "Submitted by" with other text;
- SEO optimization;
- Slideshow;
- Social Media Links at the bottom of the page;
- Remove Drupal META tag & Drupal X-Generator from header;
- Disable cache for all blocks;
- Site ID body class - useful in a multi-site environment;
- Show Logo per language.


To know more, read [the handbook] (https://drupal.org/node/507792).


Module support
----------------------------------------

This theme can support virtualy any module.

  
Theme customisation
----------------------------------------

If you feel like giving the theme a look of your own, I recommend to play with /_custom/custom-style.css; please read the comments in this file.

To change the rotating images in header you must replace the images in /_custom/headerimg or /_custom/headerimg-rtl with your own, naming them exactly like those in folder. As info, the image dimensions are 846x200 px. 
If you want to change header images rotator behaviour on mobile follow the instructions on the end of /_custom/custom-style.css.


Installation instructions
----------------------------------------

1. Place the black_hole directory into your themes directory (/themes/black_hole) or use Composer.
2. Enable the Black Hole theme (/admin/appearance).
3. Go to theme's settings at /admin/appearance/settings/black_hole and save the configuration. Remember that some of the theme's settings are multilingual variables, so you can have different settings for each language.


UPGRADING to a new version of Black Hole
----------------------------------------

1. Log in as administrator user. 
2. Put the site in "Off-line" mode.
3. Place the black_hole directory into your themes directory (/themes/black_hole) or use Composer. In case you have done some theme customization, remember to overwrite theme's custom-style.css with your modified custom-style.css file.
4. Clear cached data at /admin/config/development/performance or "Flush all caches" in Admin Menu and then press CTRL+F5;
5. Put the site in "On-line" mode. It is always a good idea to refresh the browser's cache (CTRL+F5).
6. Check the theme's settings at /admin/appearance/settings/black_hole. 


Resources
----------------------------------------

- [Yahoo Pure.css Framework](https://purecss.io)
- [Github Project Page](https://github.com/yui/pure/)
- [Pure skin builder](https://yui.github.io/skinbuilder/?mode=pure)


Sites using "Black Hole" theme
----------------------------------------

Various implementations of the Black Hole theme can be found here:
- [Demo/test site](https://www.softchannels.com/)
- [1voip](https://www.1voip.ro/)
- [Phoenix](https://www.mlnar.ro/)


Related themes
----------------------------------------

- [Zero Point](https://www.drupal.org/project/zeropoint) - a very customizable HTML5 theme;
- [ABC](https://www.drupal.org/project/abc);
- [Yahoo Pure.CSS Framework](https://www.drupal.org/project/pure_css) - an advanced responsive, mobile-first, HTML5, base-theme.


Contact
----------------------------------------

My Drupal nick is [Florian](https://www.drupal.org/u/florian) and I can be reached at florian@radut.net (https://www.radut.com).

I can also be contacted for paid customizations of the theme as well as Drupal consulting, installation and customizations.

==> black_hole-8.x-1.12.tar.gz: black_hole/Readme.md <==
*BLACK HOLE theme for Drupal 8, 9 and 10.*
========================================
Thank you for downloading this theme!


ABOUT THE BLACK HOLE THEME:
===========================

**Black Hole** is an advanced responsive, mobile first, HTML5 theme with layout and style configuration options built in that you can control through Drupal's UI. The theme is a highly customized and feature-rich design that goes beyond the basic look and feel of a typical Drupal website. It uses [Yahoo Pure.css](https://purecss.io), a powerful responsive CSS framework and also fully supports right to left languages. Pure is ridiculously tiny. The entire set of modules clocks in at 3.5KB minified and gzipped.

The theme **validates HTML5 and CSS3**, it is cross-browser compatible, and it complies with [WAVE](https://wave.webaim.org/) and [FAE](https://fae.cita.uiuc.edu/).


Theme's features
----------------------------------------

- 1, 2, or 3 column layout with customizable widths using [Yahoo Pure.css Framework](https://purecss.io);
- 15 block regions;
- 12 colour styles + themer setting. Choose themer style from theme's settings and then make appropriate modifications of /_custom/custom-style.css;
- **Helpful body classes** (unique classes for each page, term, website section, etc.);
- Themed blocks, block icons, page icons;
- Drop-down Main menu;
- Primary/secondary links menu position (center, left, right);
- Three font families;
- Different font sizes;
- Round corners for page elements and menus;
- Header image rotator;
- Full breadcrumb;
- Possibility to **change "Submitted by" display**;
- **Advanced SEO optimization**;
- Theme's own slideshow with Multilingual support. It now features two distinct variations, each comprising 7 slides: one showcasing full-page images and the other displaying half-page images.
- Social links integration;
- **Bi-directional right to left (RTL) theming**;
- The possibility of having different logos depending on the language;
- Works perfect in Multilingual installations.


Advanced theme settings features
----------------------------------------

### Pure.CSS settings

- Responsive CSS files served from Yahoo CDN or locally;
- Layout with fixed or fluid width;
- Customizable width for First and Second sidebars;
- Feature to choose the blocks visible on mobile devices.


### Layout settings

- 12 color style options: Star Nebula, Protostar, Star, Red Giant, Planetary Nebula, Planet, White Dwarf, Massive Star, Red Supergiant, Supernova, Neutron Star, Black Hole and Themer;
- Three font families (Sans-Serif, Montserrat and Merriweather);
- Three font size settings;
- Themed blocks;
- 32x32 pixel or 48x48 pixels Block icons for the themed blocks;
- Main Drop-down menu and secondary menu can be positioned (center, left, right);
- Three options for Search submit: button, icon or none;
- Page icons - choose a layout with or without page icons;
- Rounded corners for page elements and menus;
- Header image rotator;
- Duplicate the Main Menu at the bottom of the page.


### Other settings

- Breadcrumbs - display or not;
- Ability to change author and date information on all node types or differently for blog posts and forum topics;
- Replace "Submitted by" with other text;
- SEO optimization;
- Slideshow;
- Social Media Links at the bottom of the page;
- Remove Drupal META tag & Drupal X-Generator from header;
- Disable cache for all blocks;
- Site ID body class - useful in a multi-site environment;
- Show Logo per language.


To know more, read [the handbook] (https://drupal.org/node/507792).


Module support
----------------------------------------

The theme can support virtualy any module.
This versatile, **base theme** stands alone, free from dependence on other modules or libraries.

  
Theme customisation
----------------------------------------

If you feel like giving the theme a look of your own, I recommend to play with /_custom/custom-style.css; please read the comments in this file.

#### Header rotator
To change the rotating images in header you must replace the images in /_custom/headerimg or /_custom/headerimg-rtl with your own, naming them exactly like those in folder. As info, the image dimensions are 846x200 px. 
If you want to change header images rotator behaviour on mobile follow the instructions on the end of /_custom/custom-style.css.

#### Slideshow
At www.dr.mt, you'll find a compilation of pre-optimized images for your slideshow. Feel free to download them from this source, where the images are organized into sections.


Installation instructions
----------------------------------------

1. Place the black_hole directory into your themes directory (/themes/black_hole) or use Composer. In this case, the theme directory will be /themes/contrib/black_hole.
2. Enable the Black Hole theme (/admin/appearance).
3. Go to theme's settings at /admin/appearance/settings/black_hole and *save the configuration*. Remember that some of the theme's settings are multilingual variables, so you can have different settings for each language.


UPGRADING to a new version of Black Hole
----------------------------------------

1. Log in as administrator user. 
2. Put the site in "Off-line" mode.
3. Place the black_hole directory into your themes directory (/themes/black_hole) or use Composer. In case you have done some theme customization, remember to overwrite theme's custom-style.css with your modified custom-style.css file.
4. Clear cached data at /admin/config/development/performance or "Flush all caches" in Admin Menu and then press CTRL+F5;
5. Put the site in "On-line" mode. It is always a good idea to refresh the browser's cache (CTRL+F5).
6. Check the theme's settings at /admin/appearance/settings/black_hole. 


Resources
----------------------------------------

- [Yahoo Pure.css Framework](https://purecss.io)
- [Github Project Page](https://github.com/yui/pure/)
- [Pure skin builder](https://yui.github.io/skinbuilder/?mode=pure)


Sites using "Black Hole" theme
----------------------------------------

Various implementations of the Black Hole theme can be found here:
- [Demo/test site](https://www.softchannels.com/)
- [1voip](https://www.1voip.ro/)
- [Phoenix](https://www.mlnar.ro/)


Related themes
----------------------------------------

- [Zero Point](https://www.drupal.org/project/zeropoint) - a very customizable HTML5 theme;
- [ABC](https://www.drupal.org/project/abc);
- [Yahoo Pure.CSS Framework](https://www.drupal.org/project/pure_css) - an advanced responsive, mobile-first, HTML5, base-theme.


Contact
----------------------------------------

My Drupal nick is [Florian](https://www.drupal.org/u/florian) and I can be reached at florian@radut.net (https://www.radut.com).

I can also be contacted for paid customizations of the theme as well as Drupal consulting, installation and customizations.
